@@ -1,10 +1,7 @@
-import logging
 from argparse import ArgumentParser
 
 from castor_extractor.warehouse import bigquery  # type: ignore
 
-logging.basicConfig(level=logging.INFO, format="%(levelname)s - %(message)s")
-
 
 def main():
     parser = ArgumentParser()
@@ -30,6 +27,12 @@ def main():
         nargs="*",
         help="List of gcp projects that should not be extracted",
     )
+    parser.add_argument(
+        "--safe-mode",
+        "-s",
+        help="bigquery safe mode",
+        action="store_true",
+    )
 
     parser.set_defaults(skip_existing=False)
 
@@ -41,4 +44,5 @@ def main():
         skip_existing=args.skip_existing,
         db_allowed=args.db_allowed,
         db_blocked=args.db_blocked,
+        safe_mode=args.safe_mode,
     )
