@@ -7,10 +7,11 @@ from .load import load_file
 from .object import deep_serialize, getproperty
 from .pager import Pager, PagerLogger, PagerStopStrategy
 from .retry import RetryStrategy, retry
+from .safe import SafeMode, safe_mode
 from .store import AbstractStorage, LocalStorage
 from .string import string_to_tuple
 from .time import current_date, current_datetime, current_timestamp
-from .type import Callback, EntitiesType, Getter, JsonType
+from .type import Callback, Getter, JsonType, SerializedAsset
 from .uri import uri_encode
 from .validation import validate_baseurl
 from .write import (
