@@ -3,7 +3,7 @@ from urllib.error import HTTPError
 
 from requests import Response
 
-from .entities import ModeAnalyticsEntity
+from .assets import ModeAnalyticsAsset
 
 RATE_LIMIT_STATUS_CODE = 429
 
@@ -19,12 +19,12 @@ class UnexpectedApiResponseError(Exception):
 
 
 class MissingPrerequisiteError(Exception):
-    """Custom error handling case of missing entity"""
+    """Custom error handling case of missing asset"""
 
     def __init__(
         self,
-        fetched: ModeAnalyticsEntity,
-        missing: ModeAnalyticsEntity,
+        fetched: ModeAnalyticsAsset,
+        missing: ModeAnalyticsAsset,
     ):
         error_msg = f"{missing.name} must be provided to fetch {fetched.name}."
         super().__init__(error_msg)
